@@ -1,7 +1,8 @@
 """rio-tiler.expression: Parse and Apply expression."""
 
 import re
-from typing import Sequence, Tuple, Union
+import warnings
+from typing import List, Sequence, Tuple, Union
 
 import numexpr
 import numpy
@@ -12,7 +13,7 @@ def parse_expression(expression: str, cast: bool = True) -> Tuple:
 
     Args:
         expression (str): band math/combination expression.
-        cast (bool): cast band names to integers (convert to index values).
+        cast (bool): cast band names to integers (convert to index values). Defaults to True.
 
     Returns:
         tuple: band names/indexes.
@@ -29,6 +30,33 @@ def parse_expression(expression: str, cast: bool = True) -> Tuple:
     return tuple(map(int, bands)) if cast else tuple(bands)
 
 
+def get_expression_blocks(expression: str) -> List[str]:
+    """Split expression in blocks.
+
+    Args:
+        expression (str): band math/combination expression.
+
+    Returns:
+        list: expression blocks (str).
+
+    Examples:
+        >>> parse_expression("b1/b2,b2+b1")
+            ("b1/b2", "b2+b1")
+
+    """
+    if ";" in expression:
+        return [expr for expr in expression.split(";") if expr]
+
+    expr = [expr for expr in expression.split(",") if expr]
+    if len(expr) > 1:
+        warnings.warn(
+            "Using comma `,` for multiband expression will be deprecated in rio-tiler 4.0. Please use semicolon `;`.",
+            DeprecationWarning,
+        )
+
+    return expr
+
+
 def apply_expression(
     blocks: Sequence[str],
     bands: Sequence[Union[str, int]],
@@ -52,5 +80,6 @@ def apply_expression(
                 numexpr.evaluate(bloc.strip(), local_dict=dict(zip(bands, data)))
             )
             for bloc in blocks
+            if bloc
         ]
     )
