@@ -74,7 +74,7 @@ class MeanMethod(MosaicMethodBase):
             tile = numpy.ma.mean(numpy.ma.stack(self.tile, axis=0), axis=0)
             if self.enforce_data_type:
                 tile = tile.astype(self.tile[0].dtype)
-            return tile.data, ~tile.mask[0] * 255
+            return tile.data, (~tile.mask[0] * 255).astype(tile.dtype)
         else:
             return None, None
 
@@ -99,7 +99,7 @@ class MedianMethod(MosaicMethodBase):
             tile = numpy.ma.median(numpy.ma.stack(self.tile, axis=0), axis=0)
             if self.enforce_data_type:
                 tile = tile.astype(self.tile[0].dtype)
-            return tile.data, ~tile.mask[0] * 255
+            return tile.data, (~tile.mask[0] * 255).astype(tile.dtype)
         else:
             return None, None
 
@@ -121,7 +121,7 @@ class StdevMethod(MosaicMethodBase):
         """Return data and mask."""
         if self.tile:
             tile = numpy.ma.std(numpy.ma.stack(self.tile, axis=0), axis=0)
-            return tile.data, ~tile.mask[0] * 255
+            return tile.data, (~tile.mask[0] * 255).astype(tile.dtype)
         else:
             return None, None
 
@@ -137,11 +137,14 @@ class LastBandHigh(MosaicMethodBase):
     def data(self):
         """Return data and mask."""
         if self.tile is not None:
-            return self.tile.data[:-1], ~self.tile.mask[0] * 255
+            return (
+                self.tile.data[:-1],
+                (~self.tile.mask[0] * 255).astype(self.tile.dtype),
+            )
         else:
             return None, None
 
-    def feed(self, tile: numpy.ma.array):
+    def feed(self, tile: numpy.ma.MaskedArray):
         """Add data to tile."""
         if self.tile is None:
             self.tile = tile
@@ -164,11 +167,14 @@ class LastBandLow(MosaicMethodBase):
     def data(self):
         """Return data and mask."""
         if self.tile is not None:
-            return self.tile.data[:-1], ~self.tile.mask[0] * 255
+            return (
+                self.tile.data[:-1],
+                (~self.tile.mask[0] * 255).astype(self.tile.dtype),
+            )
         else:
             return None, None
 
-    def feed(self, tile: numpy.ma.array):
+    def feed(self, tile: numpy.ma.MaskedArray):
         """Add data to tile."""
         if self.tile is None:
             self.tile = tile
